@@ -156,7 +156,6 @@ class FirestoreClient(BaseClient):
         _sort: List[Tuple[str, SortOrder]] = None,
         mongo_offset: int = 0,
         fire_offset: FireOffset = None,
-        session: Any = None,
     ) -> List[DocumentDBModel]:
 
         collection_name = model.get_db_collection()
@@ -186,7 +185,7 @@ class FirestoreClient(BaseClient):
         if _limit > 0:
             query_ref = query_ref.limit(_limit)
 
-        results = await force_async(collection.stream)()
+        results = await force_async(query_ref.stream)()
 
         models: List[DocumentDBModel] = []
         for res in results:
