@@ -6,6 +6,7 @@ from fa_common import sizeof_fmt, CamelModel
 # Shared properties
 class File(CamelModel):
     size: str  # e.g. '3 KB'
+    size_bytes: int
     url: Optional[str] = None  # download url
     id: str  # id can be path or database id
     dir: bool  # is current node dir?
@@ -16,3 +17,4 @@ class File(CamelModel):
 
     def set_size(self, bytes: int):
         self.size = sizeof_fmt(bytes)
+        self.size_bytes = bytes
